Rails.application.routes.draw do
  get "leaderboard/index"
  # Reveal health status on /up that returns 200 if the app boots with no exceptions, otherwise 500.
  # Can be used by load balancers and uptime monitors to verify that the app is live.
  get "up" => "rails/health#show", as: :rails_health_check

  # Defines the root path route ("/")
  root "leaderboard#index"

  # Game
  get "game/:id", to: "game#show"
  get "games", to: "game#index", as: "games", defaults: { format: :html }

  # Only take JSON for POST to game
  resources :game, only: [ :create ], defaults: { format: :json }

  # Player
  get "player/:id", to: "player#show"

  # Leaderboard
  get "leaderboard", to: "leaderboard#index", as: "leaderboard", defaults: { format: :html }

  # Discord
  match "discord" => redirect("https://discord.gg/hQShdPMy7p"), via: [ :get ]

  # Bot
  get "bot/players" => "bot#players"
  get "bot/player/:id" => "bot#player_name"
  get "bot/summary" => "bot#summary"

  # Admin
  get "admin", to: "admin#index"
  post "admin/set_alt", to: "admin#set_alt"
  post "admin/clear_alt", to: "admin#clear_alt"
  get "admin/login", to: "admin#login"
  post "admin/login_submit", to: "admin#login_submit"
  get "admin/destroy", to: "admin#destroy"
end
